==> VirxERLU-RLib-0.1.0.tar.gz: VirxERLU-RLib-0.1.0/README.md <==
# VirxERLU

Big thanks to ddthj/GoslingUtils for the basis of VirxERLU. However, VirxERLU improves upon many things. This includes pathfinding, shot validation, and aerials. It also adds many things, like support for TMCP and a GUI for debugging. This also improves on the general performance of the agent.

+ [RLBot](http://www.rlbot.org/)
+ [VirxERLU Wiki](https://github.com/VirxEC/VirxERLU/wiki)
+ [VirxEC Discord](https://discord.gg/5ARzYRD2Na) - Ask your questions here!
+ [RLBot Wiki](https://github.com/RLBot/RLBot/wiki)
+ [RLBot Discord](https://discord.gg/rlbot)
+ [RLBot Youtube](https://www.youtube.com/channel/UCu8scB_k94Kh-iO979QTDJA)
+ [VirxEC Showcase](https://www.virxcase.dev)
+ [VirxERLU on VirxEC Showcase](https://virxerlu.virxcase.dev/)
+ [VirxEB on VirxEC Showcase](https://virxeb.virxcase.dev/)

## About

+ [Main GitHub page](https://github.com/VirxEC/VirxERLU)
+ [Cloning to another repository](https://github.com/VirxEC/VirxERLU/generate)
+ [Get the zip](https://github.com/VirxEC/VirxERLU/archive/master.zip)

VirxERLU is a series of utilities for RLBot.
All code in this repositry is in the public domain, so you can edit and distribute the code however you want to.

I made VirxERLU because it forces me to keep innovating on my bot in order to stay ahead of the curve. Any code in my bot [VirxEB](https://github.com/VirxEC/VirxEB) is NOT in the public domain.

VirxERLU will be updated after every tournament with the latest, *stable* features of VirxEB.

## Wiki

The wiki is the best way to get general information about VirxERLU.

+ [github.com/VirxEC/VirxERLU/wiki](https://github.com/VirxEC/VirxERLU/wiki)

## Tutorials

If you're going to use VirxERLU, be sure to watch the GoslingUtils tutorial first. The VirxERLU tutorial is only for the differences between the utils.

+ RLBot/GoslingUtils tutorial: [youtube.com/watch?v=lPkID_IH88U](https://www.youtube.com/watch?v=lPkID_IH88U)
+ VirxERLU tutorials: [youtube.com/playlist?list=PLeo0zkmzSE-UUFV-bd2vWtqiqe2cjaQNf](https://www.youtube.com/playlist?list=PLeo0zkmzSE-UUFV-bd2vWtqiqe2cjaQNf)

==> VirxERLU-RLib-0.3.0.tar.gz: VirxERLU-RLib-0.3.0/README.md <==
# VirxERLU

Big thanks to ddthj/GoslingUtils for the basis of VirxERLU. However, VirxERLU improves upon many things. This includes pathfinding, shot validation, and aerials. It also adds many things, like support for TMCP and a GUI for debugging. This also improves on the general performance of the agent.

+ [RLBot](http://www.rlbot.org/)
+ [VirxERLU Wiki](https://github.com/VirxEC/VirxERLU/wiki)
+ [VirxEC Discord](https://discord.gg/rutfWr4Yrw) - Ask your questions here!
+ [RLBot Wiki](https://github.com/RLBot/RLBot/wiki)
+ [RLBot Discord](https://discord.gg/rlbot)
+ [RLBot Youtube](https://www.youtube.com/channel/UCu8scB_k94Kh-iO979QTDJA)
+ [VirxEC Showcase](https://www.virxcase.dev)
+ [VirxERLU on VirxEC Showcase](https://virxerlu.virxcase.dev/)
+ [VirxEB on VirxEC Showcase](https://virxeb.virxcase.dev/)

## About

+ [Main GitHub page](https://github.com/VirxEC/VirxERLU)
+ [Cloning to another repository](https://github.com/VirxEC/VirxERLU/generate)
+ [Get the zip](https://github.com/VirxEC/VirxERLU/archive/master.zip)

VirxERLU is a series of utilities for RLBot.
All code in this repositry is in the public domain, so you can edit and distribute the code however you want to.

I made VirxERLU because it forces me to keep innovating on my bot in order to stay ahead of the curve. Any code in my bot [VirxEB](https://github.com/VirxEC/VirxEB) is NOT in the public domain.

VirxERLU will be updated after every tournament with the latest, *stable* features of VirxEB.

## Features

Currently, VirxERLU-RLib has:

+ Variable ball prediction time (default 8 seconds)
+ 120tps ball prediction analysis
+ Turn LUTs for accurate and quick turn simulations
+ Very accurate shots and distance calculations
+ Accurate 120tps acceleration simulation (coming soon)

## Wiki

The wiki is the best way to get general information about VirxERLU.

+ [github.com/VirxEC/VirxERLU/wiki](https://github.com/VirxEC/VirxERLU/wiki)

## Tutorials

If you're going to use VirxERLU, be sure to watch the GoslingUtils tutorial first. The VirxERLU tutorial is only for the differences between the utils.

+ RLBot/GoslingUtils tutorial: [youtube.com/watch?v=lPkID_IH88U](https://www.youtube.com/watch?v=lPkID_IH88U)
+ VirxERLU tutorials: [youtube.com/playlist?list=PLeo0zkmzSE-UUFV-bd2vWtqiqe2cjaQNf](https://www.youtube.com/playlist?list=PLeo0zkmzSE-UUFV-bd2vWtqiqe2cjaQNf)
